summaryrefslogtreecommitdiffstats
path: root/sys/ia64/include/globaldata.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/ia64/include/globaldata.h')
-rw-r--r--sys/ia64/include/globaldata.h17
1 files changed, 8 insertions, 9 deletions
diff --git a/sys/ia64/include/globaldata.h b/sys/ia64/include/globaldata.h
index 308086c..50f4990 100644
--- a/sys/ia64/include/globaldata.h
+++ b/sys/ia64/include/globaldata.h
@@ -44,15 +44,14 @@
* point at the globaldata structure.
*/
struct globaldata {
- struct proc *gd_curproc; /* current process */
- struct proc *gd_idleproc; /* idle process */
- struct proc *gd_fpcurproc; /* fp state owner */
- struct pcb *gd_curpcb; /* current pcb */
- struct timeval gd_switchtime;
- int gd_switchticks;
- u_int gd_cpuid; /* this cpu number */
- u_int gd_other_cpus; /* all other cpus */
- u_int64_t gd_idlepcbphys; /* pa of gd_idlepcb */
+ struct thread *gd_curthread; /* current thread */
+ struct thread *gd_idlethread; /* idle thread */
+ struct thread *gd_fpcurthread; /* fp state owner */
+ struct pcb *gd_curpcb; /* current pcb */
+ struct timeval gd_switchtime;
+ int gd_switchticks;
+ u_int gd_cpuid; /* this cpu number */
+ u_int gd_other_cpus; /* all other cpus */
u_int64_t gd_pending_ipis; /* pending IPI events */
struct pmap *gd_current_pmap; /* which pmap is active */
u_int32_t gd_next_asn; /* next ASN to allocate */
OpenPOWER on IntegriCloud